<!-- markdownlint-disable MD013 MD043 -->

# `OpenSSA`: Small Specialist Agents for Problem-Solving

`OpenSSA` is an agentic AI framework for solving complex problems in real-world industry domains,
overcoming the limitations of LLMs and RAG in such settings.

## Level-2 Intelligence with Planning, Reasoning, domain-specific Knowledge and diverse Informational Resources

`OpenSSA` agents, built with powerful Hierarchical Task Planning (HTP) and Observe-Orient-Decide-Act Reasoning (OODAR),
go far beyond the Level-1 pattern-matching intelligence performed by LLMs and RAG and achieve superior outcomes
in complex multi-faceted, multi-step tasks. See our [comparative study](https://arxiv.org/abs/2404.11792).

`OpenSSA` agents can also be armed with domain-specific Knowledge, connected to diverse Informational Resources
(files, databases, web sources, etc.), and/or be guided by specialized industry experts
to maximize the accuracy and comprehensiveness in their planning, reasoning and deliberative/iterative problem-solving.

## Open and Extensible Architecture

Committed to promoting and supporting open development in generative AI,
`OpenSSA` would strive to integrate with a diverse array of LLM backends, especially open-source LLMs.
If you would like certain LLMs to be supported, please suggest through a GitHub issue, or, even better, submit your PRs.

Additionally, `OpenSSA`'s key Planning, Reasoning, Knowledge and Resource interfaces
are designed with customizability and extensibility as first-class concerns,
in order to enable developers to effectively solve problems in their specific industries and specialized domains.

## Small and Resource-Efficient Agents for Practical Real-World Deployment

Specialized, Level-2 intelligence allows `OpenSSA` agents to work well in many applications
using significantly smaller component models, thereby greatly economizing computing resources.

## Getting Started

Install by `pip install openssa` (on Python 3.12 only).

- for bleeding-edge latest capabilities: `pip install https://github.com/aitomatic/openssa/archive/main.zip`

Explore the `examples/` directory and developer guides and tutorials on our [documentation site](https://aitomatic.github.io/openssa).

## [API Documentation](https://aitomatic.github.io/openssa/modules)

## Contributing

We welcome contributions from the community!

- Join the discussion on our [Community Forum](https://github.com/aitomatic/openssa/discussions)
- Submit pull requests for bug fixes, enhancements, or new features

For more information, see our [Contribution Guide](CONTRIBUTING.md).
